@@ -14,8 +14,8 @@ class EditJob(FlaskForm):
             Regexp(
                 "^[A-Za-z][A-Za-z0-9_. ]*$",
                 0,
-                "Job titles must have only letters, numbers, "+
-                "dots, spaces, or underscores",
+                "Job titles must have only letters, numbers, "
+                + "dots, spaces, or underscores",
             ),
         ],
     )
